# PyScratch 
For more information, see: https://kwdchan.github.io/pyscratch/



## Change History
### v2.1.0
**25 Oct 2025** 
Events and conditions can be used as a decorator (the event or condition can now be directly called as a shortcut for the add_handler method) 


### 22 Oct 2025
**v2.0.2**
Fixed the issue that the layering reset after hide and show. 

### 12 Oct 2025
**v2.0.1**
Backward compatiblity for the integer-indexed backdrop in v1

**v2.0.0**
The backdrops are now indexed by keys instead of integers


### 12 Sep 2025
**v1.0.4**  
Fixed the show/hide collision related problem due to the deferral of movement to the frame update.

### 07 Sep 2025
**v1.0.3**  
Added undeclared dependency: Pillow   
Specified the versions of the dependencies

### Jul 2025
**v1.0.0**  
The first version
